@@ -76,8 +76,6 @@ class InstallerWindow:
         self.oem_mode = oem_mode
         self.oem_config = oem_config
 
-        Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme", True)
-
         # build the setup object (where we put all our choices)
         self.setup = Setup()
         self.setup.oem_mode = oem_mode
@@ -100,6 +98,14 @@ class InstallerWindow:
         self.window.connect("delete-event", self.quit_cb)
         self.scale = self.window.get_scale_factor()
 
+        if self.oem_config:
+            self.window.connect('key-press-event', self.on_key_press)
+            self.builder.get_object("event_box").get_style_context().add_class("live-installer-welcome-oem-config")
+            self.builder.get_object("welcome_release_label").hide()
+        else:
+            Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme", True)
+            self.builder.get_object("event_box").get_style_context().add_class("live-installer-welcome")
+
         # wizard pages
         (self.PAGE_LANGUAGE,
          self.PAGE_TIMEZONE,
@@ -234,9 +240,6 @@ class InstallerWindow:
         self.column12.add_attribute(ren, "markup", 0)
         self.builder.get_object("treeview_overview").append_column(self.column12)
 
-        # install page
-        self.builder.get_object("label_install_progress").set_text(_("Calculating file indexes ..."))
-
         # i18n
         self.i18n()
 
@@ -291,6 +294,13 @@ class InstallerWindow:
 
         self.window.show_all()
 
+    def on_key_press(self, widget, event):
+        # CTRL+T key
+        if (event.state & Gdk.ModifierType.CONTROL_MASK and event.keyval == Gdk.KEY_t):
+            subprocess.Popen(['x-terminal-emulator'])
+            return True
+        return False
+
     def on_lets_go_clicked(self, button):
         self.activate_page(self.PAGE_LANGUAGE)
         self.builder.get_object("stack").set_visible_child_name("page_notebook")
@@ -305,24 +315,21 @@ class InstallerWindow:
         return True
 
     def i18n(self):
-        title = f"LMDE {VERSION} '{CODENAME}'"
-        subtitle = _("Installer")
-
-        if __debug__:
-            subtitle += ' - debug mode'
+        title = _("Installer")
         if self.oem_mode:
-            subtitle += ' - OEM mode'
+            title = "OEM Installation"
         if self.oem_config:
-            subtitle += ' - OEM config'
+            title = _("Initial Setup")
         self.builder.get_object("button_expert").set_no_show_all(True)
         if self.expert_mode:
-            subtitle += ' - expert mode'
             self.builder.get_object("button_expert").show()
         else:
             self.builder.get_object("button_expert").hide()
 
+        if __debug__:
+            self.builder.get_object("debug_label").set_text("Debug mode")
+
         self.builder.get_object("headerbar").set_title(title)
-        self.builder.get_object("headerbar").set_subtitle(subtitle)
 
         # Header
         self.wizard_pages = list(range(11))
@@ -344,9 +351,25 @@ class InstallerWindow:
         self.builder.get_object("button_next").set_label(_("Next"))
 
         # Welcome page
-        self.builder.get_object("label_welcome1").set_text(_("Welcome to %s!") % f"LMDE {VERSION}")
-        self.builder.get_object("label_welcome2").set_text(_("This program will ask you some questions and set up LMDE on your computer."))
-        self.builder.get_object("button_lets_go").set_label(_("Let's go!"))
+        self.builder.get_object("welcome_release_label").set_text(_("Welcome to %s!") % f"LMDE {VERSION}")
+        image_widget = self.builder.get_object("welcome_image")
+        if self.oem_config:
+            # Localized to the language chosen by the manufacturer
+            pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale("/usr/share/live-installer/welcome.svg", -1, 400 * self.scale, True)
+            self.builder.get_object("welcome_label").set_markup("<b><span size='large'>%s</span></b>" % _("Welcome to your new computer!"))
+            self.builder.get_object("welcome_button_label").set_markup("<b><span size='large'>%s</span></b>" % _("Start"))
+        elif self.oem_mode:
+            # Always in English
+            pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale("/usr/share/live-installer/logo.svg", -1, 150 * self.scale, True)
+            self.builder.get_object("welcome_label").set_text(f"This program will pre-install LMDE on this computer.")
+            self.builder.get_object("welcome_button_label").set_label("Let's go!")
+        else:
+            # Always in English
+            pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale("/usr/share/live-installer/logo.svg", -1, 150 * self.scale, True)
+            self.builder.get_object("welcome_label").set_text("This program will ask you some questions and install LMDE on your computer.")
+            self.builder.get_object("welcome_button_label").set_label("Let's go!")
+        surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf, self.scale, image_widget.get_window())
+        image_widget.set_from_surface(surface)
 
         # Language page
         self.language_column.set_title(_("Language"))
@@ -416,6 +439,8 @@ class InstallerWindow:
         self.builder.get_object("label_custom_install_paused_4").set_label(_("Note that in order for update-initramfs to work properly in some cases (such as dm-crypt), you may need to have drives currently mounted using the same block device name as they appear in /target/etc/fstab."))
         self.builder.get_object("label_custom_install_paused_5").set_label(_("Double-check that your /target/etc/fstab is correct, matches what your new system will have at first boot, and matches what is currently mounted at /target."))
 
+        self.builder.get_object("label_install_progress").set_text(_("Calculating file indexes ..."))
+
         # Refresh the current title and help question in the page header
         self.activate_page(self.PAGE_LANGUAGE)
 
@@ -608,7 +633,7 @@ class InstallerWindow:
         self.builder.get_object("button_next").set_sensitive(not error)
 
     def quit_cb(self, widget, data=None):
-        if QuestionDialog(_("Quit?"), _("Are you sure you want to quit the installer?")):
+        if QuestionDialog(_("Quit?"), _("Are you sure you want to quit?")):
             Gtk.main_quit()
             return False
         else:
